========
Usage
========

Installing services
-------------------

To install a service ``kolla-kubernetes run <service>``

Destroying services
-------------------

To remove a service ``kolla-kubernetes kill <service>``

Debugging
---------

Add a ``-d`` flag to the CLI activate debug mode.